RfwGenException class
Exception thrown when RFW code generation encounters one or more issues.
Contains a list of RfwGenIssues describing all problems found.
- Implemented types
Constructors
-
RfwGenException(List<
RfwGenIssue> issues) -
Creates an exception from the given
issues.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
RfwGenIssue> -
The list of issues that caused this exception.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited